==> qt4-devel-4.4.3-1.tar.bz2: include/qt4/Qt/qconfig.h <==
/* Everything */

#ifndef QT_DLL
#define QT_DLL
#endif

/* License information */
#define QT_PRODUCT_LICENSEE "Open Source"
#define QT_PRODUCT_LICENSE "OpenSource"

// Qt Edition
#ifndef QT_EDITION
#  define QT_EDITION QT_EDITION_OPENSOURCE
#endif

#if (defined(_DEBUG) || defined(DEBUG))
# if (defined(WIN64) || defined(_WIN64) || defined(__WIN64__))
#  define QT_BUILD_KEY "Windows x64 msvc debug full-config"
# else
#  define QT_BUILD_KEY "Windows msvc debug full-config"
# endif
#else
# if (defined(WIN64) || defined(_WIN64) || defined(__WIN64__))
#  define QT_BUILD_KEY "Windows x64 msvc release full-config"
# else
#  define QT_BUILD_KEY "Windows msvc release full-config"
# endif
#endif

/* Machine byte-order */
#define Q_BIG_ENDIAN 4321
#define Q_LITTLE_ENDIAN 1234
#define Q_BYTE_ORDER Q_LITTLE_ENDIAN

// Compile time features
#define QT_ARCH_WINDOWS
#if defined(QT_NO_DBUS) && defined(QT_DBUS)
# undef QT_NO_DBUS
#elif !defined(QT_NO_DBUS)
# define QT_NO_DBUS
#endif

#if defined(QT_NO_DIRECT3D) && defined(QT_DIRECT3D)
# undef QT_NO_DIRECT3D
#elif !defined(QT_NO_DIRECT3D)
# define QT_NO_DIRECT3D
#endif

#if defined(QT_NO_OPENSSL) && defined(QT_OPENSSL)
# undef QT_NO_OPENSSL
#elif !defined(QT_NO_OPENSSL)
# define QT_NO_OPENSSL
#endif

#if defined(QT_NO_STYLE_WINDOWSCE) && defined(QT_STYLE_WINDOWSCE)
# undef QT_NO_STYLE_WINDOWSCE
#elif !defined(QT_NO_STYLE_WINDOWSCE)
# define QT_NO_STYLE_WINDOWSCE
#endif

#if defined(QT_NO_STYLE_WINDOWSMOBILE) && defined(QT_STYLE_WINDOWSMOBILE)
# undef QT_NO_STYLE_WINDOWSMOBILE
#elif !defined(QT_NO_STYLE_WINDOWSMOBILE)
# define QT_NO_STYLE_WINDOWSMOBILE
#endif

#if defined(QT_NO_STYLE_WINDOWSVISTA) && defined(QT_STYLE_WINDOWSVISTA)
# undef QT_NO_STYLE_WINDOWSVISTA
#elif !defined(QT_NO_STYLE_WINDOWSVISTA)
# define QT_NO_STYLE_WINDOWSVISTA
#endif

#if defined(QT_SQL_ODBC) && defined(QT_NO_SQL_ODBC)
# undef QT_SQL_ODBC
#elif !defined(QT_SQL_ODBC)
# define QT_SQL_ODBC
#endif

#if defined(QT_SQL_PSQL) && defined(QT_NO_SQL_PSQL)
# undef QT_SQL_PSQL
#elif !defined(QT_SQL_PSQL)
# define QT_SQL_PSQL
#endif

==> qt4-devel-4.5.2-9.tar.bz2: include/qt4/Qt/qconfig.h <==
/* Everything */

#ifndef QT_DLL
#define QT_DLL
#endif

/* License information */
#define QT_PRODUCT_LICENSEE "Open Source"
#define QT_PRODUCT_LICENSE "OpenSource"

// Qt Edition
#ifndef QT_EDITION
#  define QT_EDITION QT_EDITION_OPENSOURCE
#endif

#if (defined(_DEBUG) || defined(DEBUG))
# if (defined(WIN64) || defined(_WIN64) || defined(__WIN64__))
#  define QT_BUILD_KEY "Windows x64 msvc debug full-config"
# else
#  define QT_BUILD_KEY "Windows msvc debug full-config"
# endif
#else
# if (defined(WIN64) || defined(_WIN64) || defined(__WIN64__))
#  define QT_BUILD_KEY "Windows x64 msvc release full-config"
# else
#  define QT_BUILD_KEY "Windows msvc release full-config"
# endif
#endif

/* Machine byte-order */
#define Q_BIG_ENDIAN 4321
#define Q_LITTLE_ENDIAN 1234
#define Q_BYTE_ORDER Q_LITTLE_ENDIAN

// Compile time features
#define QT_ARCH_WINDOWS
#if defined(QT_GRAPHICSSYSTEM_RASTER) && defined(QT_NO_GRAPHICSSYSTEM_RASTER)
# undef QT_GRAPHICSSYSTEM_RASTER
#elif !defined(QT_GRAPHICSSYSTEM_RASTER)
# define QT_GRAPHICSSYSTEM_RASTER
#endif

#if defined(QT_NO_DBUS) && defined(QT_DBUS)
# undef QT_NO_DBUS
#elif !defined(QT_NO_DBUS)
# define QT_NO_DBUS
#endif

#if defined(QT_NO_DIRECT3D) && defined(QT_DIRECT3D)
# undef QT_NO_DIRECT3D
#elif !defined(QT_NO_DIRECT3D)
# define QT_NO_DIRECT3D
#endif

#if defined(QT_NO_STYLE_GTK) && defined(QT_STYLE_GTK)
# undef QT_NO_STYLE_GTK
#elif !defined(QT_NO_STYLE_GTK)
# define QT_NO_STYLE_GTK
#endif

#if defined(QT_NO_STYLE_WINDOWSCE) && defined(QT_STYLE_WINDOWSCE)
# undef QT_NO_STYLE_WINDOWSCE
#elif !defined(QT_NO_STYLE_WINDOWSCE)
# define QT_NO_STYLE_WINDOWSCE
#endif

#if defined(QT_NO_STYLE_WINDOWSMOBILE) && defined(QT_STYLE_WINDOWSMOBILE)
# undef QT_NO_STYLE_WINDOWSMOBILE
#elif !defined(QT_NO_STYLE_WINDOWSMOBILE)
# define QT_NO_STYLE_WINDOWSMOBILE
#endif

#if defined(QT_NO_STYLE_WINDOWSVISTA) && defined(QT_STYLE_WINDOWSVISTA)
# undef QT_NO_STYLE_WINDOWSVISTA
#elif !defined(QT_NO_STYLE_WINDOWSVISTA)
# define QT_NO_STYLE_WINDOWSVISTA
#endif

#if defined(QT_SQL_ODBC) && defined(QT_NO_SQL_ODBC)
# undef QT_SQL_ODBC
#elif !defined(QT_SQL_ODBC)
# define QT_SQL_ODBC
#endif

#if defined(QT_SQL_PSQL) && defined(QT_NO_SQL_PSQL)
# undef QT_SQL_PSQL
#elif !defined(QT_SQL_PSQL)
# define QT_SQL_PSQL
#endif
